@@ -173,6 +173,9 @@ class InteractiveShell(cmd.Cmd):
         if hasattr(args, "no_patch") and args.no_patch:
             options_info.append(f"  ZeepPatcher   : {colorize('Disabled', 'red')}")
 
+        if hasattr(args, "wsdl") and args.wsdl:
+            options_info.append(f"  Custom WSDL   : {colorize(args.wsdl, 'yellow')}")
+
         if (
             hasattr(args, "health_check_interval") and args.health_check_interval != 10
         ):  # 10 is default
@@ -191,7 +194,7 @@ class InteractiveShell(cmd.Cmd):
             "  / __ \\/ | / / |  / /  _/ ____/",
             " / / / /  |/ /| | / // // /_    ",
             "/ /_/ / /|  / | |/ // // __/    ",
-            "\\____/_/ |_/  |___/___/_/  v0.1.8",
+            "\\____/_/ |_/  |___/___/_/  v0.1.9",
             "                                ",
         ]
 
@@ -1268,6 +1271,11 @@ class InteractiveShell(cmd.Cmd):
         if hasattr(self.args, "no_patch") and self.args.no_patch:
             options_info.append(f"  ZeepPatcher   : {colorize('Disabled', 'red')}")
 
+        if hasattr(self.args, "wsdl") and self.args.wsdl:
+            options_info.append(
+                f"  Custom WSDL   : {colorize(self.args.wsdl, 'yellow')}"
+            )
+
         if (
             hasattr(self.args, "health_check_interval")
             and self.args.health_check_interval != 10
@@ -1385,7 +1393,7 @@ class InteractiveShell(cmd.Cmd):
             super().do_help(line)
         else:
             help_text = f"""
-{colorize('ONVIF Interactive Shell — v0.1.8', 'cyan')}\n{colorize('https://github.com/nirsimetri/onvif-python', 'white')}
+{colorize('ONVIF Interactive Shell — v0.1.9', 'cyan')}\n{colorize('https://github.com/nirsimetri/onvif-python', 'white')}
 
 {colorize('Basic Commands:', 'yellow')}
   capabilities, caps       - Show device capabilities
